@@ -209,11 +209,17 @@ class IMAPFolder(BaseFolder):
 
             Returns: range(s) for messages or None if no messages
             are to be fetched."""
-            res_type, res_data = imapobj.search(None, search_conditions)
-            if res_type != 'OK':
+            try:
+                res_type, res_data = imapobj.search(None, search_conditions)
+                if res_type != 'OK':
+                    raise OfflineImapError("SEARCH in folder [%s]%s failed. "
+                        "Search string was '%s'. Server responded '[%s] %s'"% (
+                            self.getrepository(), self, search_cond, res_type, res_data),
+                        OfflineImapError.ERROR.FOLDER)
+            except Exception as e:
                 raise OfflineImapError("SEARCH in folder [%s]%s failed. "
-                    "Search string was '%s'. Server responded '[%s] %s'"% (
-                    self.getrepository(), self, search_cond, res_type, res_data),
+                        "Search string was '%s'. Error: %s"% (
+                            self.getrepository(), self, search_cond, str(e)),
                     OfflineImapError.ERROR.FOLDER)
             # Davmail returns list instead of list of one element string.
             # On first run the first element is empty.
@@ -722,22 +728,32 @@ class IMAPFolder(BaseFolder):
                         OfflineImapError.ERROR.MESSAGE)
                 if uid == 0:
                     self.ui.warn("savemessage: Server supports UIDPLUS, but"
-                        " we got no usable uid back. APPENDUID reponse was "
+                        " we got no usable UID back. APPENDUID reponse was "
                         "'%s'"% str(resp))
             else:
-                # We don't support UIDPLUS.
-                uid = self.__savemessage_searchforheader(imapobj, headername,
-                    headervalue)
-                # See docs for savemessage in Base.py for explanation
-                # of this and other return values.
-                if uid == 0:
-                    self.ui.debug('imap', 'savemessage: attempt to get new UID '
-                        'UID failed. Search headers manually.')
-                    uid = self.__savemessage_fetchheaders(imapobj, headername,
+                try:
+                    # We don't use UIDPLUS.
+                    uid = self.__savemessage_searchforheader(imapobj, headername,
                         headervalue)
-                    self.ui.warn("savemessage: Searching mails for new "
-                        "Message-ID failed. Could not determine new UID "
-                        "on %s."% self.getname())
+                    # See docs for savemessage in Base.py for explanation
+                    # of this and other return values.
+                    if uid == 0:
+                        self.ui.debug('imap', 'savemessage: attempt to get new UID '
+                            'UID failed. Search headers manually.')
+                        uid = self.__savemessage_fetchheaders(imapobj, headername,
+                            headervalue)
+                        self.ui.warn("savemessage: Searching mails for new "
+                            "Message-ID failed. Could not determine new UID "
+                            "on %s."% self.getname())
+                # Something wrong happened while trying to get the UID. Explain
+                # the error might be about the 'get UID' process not necesseraly
+                # the APPEND.
+                except Exception:
+                    self.ui.warn("%s: could not determine the UID while we got "
+                        "no error while appending the email with '%s: %s'"%
+                        (self.getname(), headername, headervalue)
+                    )
+                    raise
         finally:
             if imapobj:
                 self.imapserver.releaseconnection(imapobj)
